import React, { FC, useEffect, useState } from 'react';
import { styles } from './MutlitSelectStyles';
import { Item, Label, NativeBase, Text, View, Icon } from 'native-base';
import { ScrollView, TouchableOpacity } from 'react-native';
import { SelectSearchBar } from './SelectSearchBar';

export type ItemProp = { label: string; value: string };
export type MultiSelectTagDropDownProps = {
  type: 'bordered' | 'primary';
  pickerList: ItemProp[];
  label?: string;
  labelProps?: NativeBase.Label;
  onChange: (val: string[]) => void;
  validationInfo?: string[];
  tagColor?: string;
  value?: string[];
};
export const MultiSelectDropDown: FC<MultiSelectTagDropDownProps> = (
  props: MultiSelectTagDropDownProps
) => {
  const {
    label,
    labelProps,
    pickerList,
    onChange,
    validationInfo,
    value,
    type,
    tagColor
  } = props;
  const [showPickerList, setShowPickerList] = useState<boolean>(false);
  const [pickedList, setPickedList] = useState<ItemProp[]>([]);
  const removeItem = (val: ItemProp) => {
    const temp = pickedList.filter((item) => item.value !== val.value);
    setPickedList(temp);
    onChange(temp.map((item) => item.value));
  };
  const renderTags = () => {
    if (pickedList.length === 0) {
      return (
        <Text style={{ marginTop: 5, marginBottom: 5, color: '#C4C4C4' }}>
          Click to select
        </Text>
      );
    }
    return pickedList.map((item, index) => {
      return (
        <View style={[styles.tagContainer, {backgroundColor: tagColor ?? '#FD8282'}]} key={index}>
          <Text style={{ marginRight: 5, color: 'white' }}>{item.label}</Text>
          <Icon
            style={{ color: 'white', fontSize: 15 }}
            name={'close'}
            fontSize={10}
            onPress={() => removeItem(item)}
          />
        </View>
      );
    });
  };
  const onComplete = (val: ItemProp[]) => {
    setPickedList(val);
    onChange(val.map((item) => item.value));
  };
  useEffect(() => {
    if (value && value.length > 0) {
      const temp = pickerList.filter((item) => value.includes(item.value));
      console.log('vieeyy ', temp);
      setPickedList(temp);
    }
  }, []);
  const renderElement = (selectStyleX?: any, labelStyle?: any) => {
    return (
      <Item stackedLabel={label !== undefined} style={styles.itemStyle}>
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps?.style as object) }
                : labelStyle
            }
          >
            {label}
            {'   '}
            {validationInfo && validationInfo?.length > 0 && (
              <Text style={{ color: '#f39c12', marginLeft: 5 }}>
                {validationInfo}
              </Text>
            )}
          </Label>
        )}
        <TouchableOpacity
          style={styles.default}
          onPress={() => setShowPickerList(!showPickerList)}
        >
          <ScrollView>
            <View style={selectStyleX}>{renderTags()}</View>
          </ScrollView>
        </TouchableOpacity>
        <SelectSearchBar
          onComplete={onComplete}
          data={pickerList}
          showModal={showPickerList}
          closeModal={() => setShowPickerList(false)}
          value={pickedList}
        />
      </Item>
    );
  };
  switch (type) {
    case 'bordered':
      return renderElement(
        { ...styles.bordered },
        {
          ...styles.textDefault,
          color: '#979797',
        }
      );
    default:
      return renderElement(styles.multiSelect, styles.textDefault);
  }
};
