import React, { useEffect, useState } from 'react';
import { Icon, Input, Item, ListItem, Text, View, Spinner } from 'native-base';
import { Dimensions, StyleSheet, Modal, FlatList } from 'react-native';
import { ItemProp } from './MultiSelectDropDown';

const { width } = Dimensions.get('window');
const styles = StyleSheet.create({
  barContainer: {
    padding: 5,
    justifyContent: 'center',
    flexDirection: 'row',
  },
  searchInput: {
    borderWidth: 3,
    backgroundColor: '#f2f2f7',
    borderRadius: 20,
    margin: 6,
    padding: 10,
    justifyContent: 'center',
    flexDirection: 'row',
    height: 45,
    width: width * 0.8,
  },
  icon: {},
  doneButton: {
    alignItems: 'center',
    justifyContent: 'center',
    margin: 10,
    flexDirection: 'row',
    borderBottomWidth: 0,
  },
  cancel: {
    color: '#5FC9F8',
  },
});
type Props = {
  data: ItemProp[];
  placeholder?: string;
  value?: ItemProp[];
  showModal: boolean;
  closeModal: () => void;
  onComplete: (val: ItemProp[]) => void;
};
export const SelectSearchBar = (props: Props) => {
  const { placeholder, data, value, showModal, closeModal, onComplete } = props;
  const [isEditing, setIsEditing] = useState<boolean>(false);
  const [display, setDisplay] = useState<boolean>(false);
  const [pickedList, setPickedList] = useState<ItemProp[]>([]);
  // const [searchString, setSearchString] = useState<string>('');
  // const [data, setData] = useState<string[]>([]);
  const [selected, setSelected] = React.useState(new Map());

  const onSelect = React.useCallback(
    (value) => {
      const newSelected = new Map(selected);
      newSelected.set(value, !selected.get(value));
      setSelected(newSelected);
    },
    [selected]
  );

  const onchangeText = (text: string) => {
    setIsEditing(text !== '');
    // setSearchString(text);
    // onSelect(text, false);
  };
  const handlerChanged = (val: ItemProp) => {
    const temp = pickedList;
    onSelect(val.value);
    const index = temp.findIndex((item) => item.value === val.value);
    if (index === -1) {
      temp.push(val);
    } else {
      temp.splice(index, 1);
    }
    setPickedList(temp);
    setDisplay(false);
  };
  // const handleKeyDown = (e: { nativeEvent: { key: string } }) => {
  //   alert('yo');
  //   if (e.nativeEvent.key == 'Enter') {
  //     alert('go');
  //     Keyboard.dismiss();
  //   }
  // };
  const doneSelect = () => {
    onComplete(pickedList);
    selected.clear();
    closeModal();
  };
  useEffect(() => {
    if (value) {
      setPickedList(value);
      for (const item of value) {
        const temp = selected;
        temp.set(item.value, true);
        setSelected(temp);
      }
    }
  }, [value]);
  return (
    <Modal visible={showModal} onDismiss={closeModal}>
      <View>
        <View style={styles.barContainer}>
          <View>
            <Item
              style={styles.searchInput}
              onPress={() => setDisplay(!display)}
            >
              <Input
                placeholder={placeholder ? placeholder : 'Search'}
                onChangeText={onchangeText}
                autoFocus={true}
                returnKeyType={'done'}
                // onKeyPress={handleKeyDown}
                // onSubmitEditing={(e) => handlerChanged(e.nativeEvent.text)}
              />
              <Icon
                style={styles.icon}
                onPress={() => {
                  // setSearchString('');
                  setIsEditing(false);
                  setDisplay(false);
                  // setData([]);
                }}
                name={isEditing || value !== undefined ? 'close' : 'ios-search'}
              />
            </Item>
          </View>
          <Item style={styles.doneButton}>
            <Text style={styles.cancel} onPress={doneSelect}>
              Done
            </Text>
          </Item>
        </View>
        {data.length === 0 ? (
          <Spinner color="green" />
        ) : (
          <FlatList
            // style={{marginTop: 60}}
            maxToRenderPerBatch={10}
            data={data}
            renderItem={({ item, index }) => (
              <ListItem
                key={index}
                style={{ marginRight: 15, marginLeft: 15 }}
                onPress={() => handlerChanged(item)}
              >
                <Text
                  style={{
                    color: !!selected.get(item.value) ? '#FD8282' : 'black',
                  }}
                >
                  {item.label}
                </Text>
              </ListItem>
            )}
            keyExtractor={(item: ItemProp) => item.value}
            extraData={selected}
            scrollEnabled
            style={{ marginBottom: 80 }}
          />
        )}
      </View>
    </Modal>
  );
};
