import React, { FC, useContext, useEffect, useState } from 'react';
import { Icon, Item, Label, NativeBase, Text, View } from 'native-base';
import { styles } from './style';
import { ScrollView, TouchableOpacity } from 'react-native';
import { ItemProp } from '../MultiSelect/MultiSelectDropDown';
import { DropdownList } from './DropdownList';
import TreeDropdownContext from './TreeDropdownContext';

export type TreeItemProp = {
  parent: ItemProp;
  children: ItemProp[];
  color?: string;
};
export type RemoveItemProps = {
  parentId: string;
  childId: string;
  action: 'remove' | 'neutral';
};
export type TreeDropdownProps = {
  type: 'bordered' | 'primary';
  pickerList: TreeItemProp[];
  parentName: string;
  childName: string;
  label?: string;
  labelProps?: NativeBase.Label;
  onChange: (val?: string[]) => void;
  validationInfo?: string[];
  value?: any[];
};
export const TreeDropdown: FC<TreeDropdownProps> = (
  props: TreeDropdownProps
) => {
  const {
    label,
    labelProps,
    pickerList,
    onChange,
    validationInfo,
    value,
    type,
    childName,
    parentName,
  } = props;
  const renderElement = (selectStyleX?: any, labelStyle?: any) => {
    const [showPickerList, setShowPickerList] = useState<boolean>(false);
    const context = useContext(TreeDropdownContext).current!;
    const { removeTag, setSelectedList, selectedList } = context;
    useEffect(() => {
      if (value) {
        setSelectedList(value);
      }
    }, [value]);
    const renderTags = () => {
      if (selectedList.length === 0) {
        return (
          <Text style={{ marginTop: 5, marginBottom: 5, color: '#C4C4C4' }}>
            Select
          </Text>
        );
      }
      return selectedList.map((item: any, ind: number) => {
        return item[childName].map((val: string, index: number) => (
          <View
            style={[
              styles.tagContainer,
              {
                backgroundColor:
                  pickerList.find(
                    (clr) => clr.parent.value === item[parentName]
                  )?.color ?? '#FD8282',
              },
            ]}
            key={`${ind}${index}`}
          >
            <Text style={{ marginRight: 5, color: 'white' }}>
              {item[parentName]} {` `} {val}
            </Text>
            <Icon
              style={{ color: 'white', fontSize: 15 }}
              name={'close'}
              fontSize={10}
              onPress={() =>
                removeTag({
                  action: 'remove',
                  childId: val,
                  parentId: item[parentName],
                })
              }
            />
          </View>
        ));
      });
    };
    const onComplete = (val: any[]) => {
      onChange(val.length === 0 ? undefined : val);
      setSelectedList(val);
    };
    return (
      <Item stackedLabel={label !== undefined} style={styles.itemStyle}>
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps?.style as object) }
                : labelStyle
            }
          >
            {label}
            {'   '}
            {validationInfo && validationInfo?.length > 0 && (
              <Text style={{ color: '#f39c12', marginLeft: 5 }}>
                {validationInfo}
              </Text>
            )}
          </Label>
        )}
        <TouchableOpacity
          style={styles.default}
          onPress={() => setShowPickerList(!showPickerList)}
        >
          <ScrollView>
            <View style={selectStyleX}>{renderTags()}</View>
          </ScrollView>
          <DropdownList
            onChange={onComplete}
            parentName={parentName}
            childName={childName}
            data={pickerList}
            showModal={showPickerList}
            closeModal={() => setShowPickerList(false)}
            value={value}
          />
        </TouchableOpacity>
      </Item>
    );
  };
  switch (type) {
    case 'bordered':
      return renderElement(
        { ...styles.bordered },
        {
          ...styles.textDefault,
          color: '#979797',
        }
      );
    default:
      return renderElement(styles.multiSelect, styles.textDefault);
  }
};
