import React, { FC, useMemo, useState } from 'react';
import { styles } from './styles';
import {
  Item,
  Label,
  NativeBase,
  RnViewStyleProp,
  Text,
  View,
} from 'native-base';
import { TouchableOpacity, Image } from 'react-native';
import { default as ImagePickerX } from 'react-native-image-picker';
import { ImagePickerOptions } from 'react-native-image-picker/src/internal/types';

// type imageDataProps = {
//   src: string;
//   dataBase64: string;
// };
export type ImageUploaderProps = {
  type?: 'avatar' | 'primary';
  ImagePickerStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  labelProps?: NativeBase.Label;
  validationInfo?: string[];
  onChange: (val: string) => void;
  value?: string;
  pickerOptions?: ImagePickerOptions;
};
export const ImagePicker: FC<ImageUploaderProps> = (
  props: ImageUploaderProps
) => {
  const {
    type,
    label,
    labelProps,
    style,
    ImagePickerStyle,
    validationInfo,
    onChange,
    value,
    pickerOptions,
  } = props;
  const [image, setImage] = useState<{ uri: string }>();
  const options: ImagePickerOptions = {
    title: 'Select Picture',
    mediaType: 'photo',
    allowsEditing: true,
    quality: 0.7,
    // storageOptions: {
    //   skipBackup: true,
    //   path: 'images',
    // },
    maxWidth: type === 'avatar' ? 300 : 1000,
    maxHeight: type === 'avatar' ? 300 : 700,
  };
  // useEffect(() => {
  //  if(type === 'avatar'){
  //    setImageProps({
  //
  //    })
  //  }
  // })
  const onPress = () => {
    ImagePickerX.showImagePicker(
      pickerOptions ? { ...options, ...pickerOptions } : options,
      (response) => {
        if (response.didCancel) {
          console.log('User cancelled image picker');
        } else if (response.error) {
          console.log('ImagePicker Error: ', response.error);
        } else if (response.customButton) {
          console.log('User tapped custom button: ', response.customButton);
        } else {
          setImage({ uri: response.uri });
          onChange(`data:image/png;base64,${response.data}`);
        }
      }
    );
  };
  const imageSrc = useMemo(() => {
    if (value && (value === image?.uri || image?.uri === undefined)) {
      return { uri: value };
    }
    return image;
  }, [value, image]);
  const renderElement = (pickerStyleX?: any) => {
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...styles.textDefault, ...(labelProps.style as object) }
                : styles.textDefault
            }
          >
            {label}
            {'   '}
            {validationInfo && validationInfo?.length > 0 && (
              <Text style={{ color: '#f39c12', marginLeft: 5 }}>
                {validationInfo}
              </Text>
            )}
          </Label>
        )}
        <TouchableOpacity onPress={onPress}>
          {!imageSrc ? (
            <View
              style={
                ImagePickerStyle
                  ? { ...ImagePickerStyle, ...pickerStyleX }
                  : pickerStyleX
              }
            >
              <Image
                style={{ height: 50, width: 50 }}
                source={require('./ImageIcon.png')}
              />
            </View>
          ) : (
            <Image
              source={imageSrc}
              // resizeMethod={'resize'}
              resizeMode={type === 'avatar' ? undefined : 'cover'}
              style={
                ImagePickerStyle
                  ? { ...ImagePickerStyle, ...pickerStyleX }
                  : pickerStyleX
              }
            />
          )}
        </TouchableOpacity>
      </Item>
    );
  };
  if (type === 'avatar') {
    return renderElement(styles.avatar);
  }
  return renderElement(styles.defaultImage);
};
