import React, { FC } from 'react';
import {
  Textarea as TextareaX,
  Item,
  Label,
  NativeBase,
  RnViewStyleProp,
  Text,
} from 'native-base';
import { styles } from './styles';

type Props = NativeBase.Textarea & {
  type?: 'material' | 'primary' | 'bordered';
  TextareaStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  labelProps?: NativeBase.Label;
  TextareaProps?: NativeBase.Textarea;
  validationInfo?: string[];
  // children: ReactNode;
};
export const Textarea: FC<Props> = (props: Props) => {
  const {
    type,
    label,
    labelProps,
    style,
    TextareaStyle,
    validationInfo,
  } = props;
  const propsX = { ...props };
  propsX.style = TextareaStyle;
  delete propsX.labelProps;
  delete propsX.type;
  delete propsX.label;
  delete propsX.TextareaStyle;

  const renderElement = (inputStyleX?: any, labelStyle?: any) => {
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
            {'   '}
            {validationInfo && validationInfo?.length > 0 && (
              <Text style={{ color: '#f39c12', marginLeft: 5 }}>
                {validationInfo}
              </Text>
            )}
          </Label>
        )}

        <TextareaX
          {...propsX}
          placeholderTextColor={'#C4C4C4'}
          style={
            TextareaStyle ? { ...inputStyleX, ...TextareaStyle } : inputStyleX
          }
        />
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(styles.material, styles.textMaterial);
    case 'bordered':
      return renderElement(styles.bordered, {
        ...styles.textDefault,
        color: '#979797',
      });
    default:
      return renderElement(styles.default, styles.textDefault);
  }
};
